@@ -1,6 +1,8 @@
 '''Package containing simple scripts for plotting objects ``dustpy.Simulation``
 or data files.'''
 
+from dustpy.plot.plot import ipanel
 from dustpy.plot.plot import panel
 
-__all__ = ["panel"]
+__all__ = ["ipanel", "panel"]
+__version__ = None
