@@ -8,6 +8,7 @@ from matplotlib.widgets import Slider
 from scipy.interpolate import interp1d
 from simframe.io.writers import hdf5writer
 import os
+import warnings
 
 
 def panel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limits=True, show_St1=True):
@@ -38,13 +39,13 @@ def panel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limits
     # Fix indices if necessary
     it = np.maximum(0, it)
     it = np.minimum(it, data.Nt-1)
-    it = np.int(it)
+    it = int(it)
     im = np.maximum(0, im)
     im = np.minimum(im, data.Nm[it, ...]-1)
-    im = np.int(im)
+    im = int(im)
     ir = np.maximum(0, ir)
     ir = np.minimum(ir, data.Nr[it, ...]-1)
-    ir = np.int(ir)
+    ir = int(ir)
 
     # Get limits/levels
     sd_max = np.ceil(np.log10(data.sigmaDust.max()))
@@ -100,7 +101,7 @@ def panel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limits
     cbar00.ax.set_ylabel("$\sigma_\mathrm{d}$ [g/cm²]")
     cbar00ticklabels = []
     for i in levels:
-        cbar00ticklabels.append("$10^{{{:d}}}$".format(np.int(i)))
+        cbar00ticklabels.append("$10^{{{:d}}}$".format(int(i)))
     cbar00.ax.set_yticklabels(cbar00ticklabels)
     ax00.set_xscale("log")
     ax00.set_yscale("log")
@@ -187,13 +188,13 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
     # Fix indices if necessary
     it = np.maximum(0, it)
     it = np.minimum(it, data.Nt-1)
-    it = np.int(it)
+    it = int(it)
     im = np.maximum(0, im)
     im = np.minimum(im, data.Nm[it, ...]-1)
-    im = np.int(im)
+    im = int(im)
     ir = np.maximum(0, ir)
     ir = np.minimum(ir, data.Nr[it, ...]-1)
-    ir = np.int(ir)
+    ir = int(ir)
 
     # Get limits/levels
     sd_max = np.ceil(np.log10(data.sigmaDust.max()))
@@ -252,7 +253,7 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
     cbar00.ax.set_ylabel("$\sigma_\mathrm{d}$ [g/cm²]")
     cbar00ticklabels = []
     for i in levels:
-        cbar00ticklabels.append("$10^{{{:d}}}$".format(np.int(i)))
+        cbar00ticklabels.append("$10^{{{:d}}}$".format(int(i)))
     cbar00.ax.set_yticklabels(cbar00ticklabels)
     ax00.set_xscale("log")
     ax00.set_yscale("log")
@@ -323,8 +324,8 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
                                  0.375,
                                  0.75 * width,
                                  0.02], facecolor="lightgoldenrodyellow")
-        sliderTime = Slider(axSliderTime, "Time", 0, data.Nt -
-                            1, valinit=it, valfmt="%i")
+        sliderTime = Slider(axSliderTime, "Time", 0, int(data.Nt -
+                            1), valinit=it, valfmt="%i")
         axSliderTime.set_title("t = {:9.3e} yr".format(data.t[it]/c.year))
         fig._widgets += [sliderTime]
 
@@ -333,7 +334,7 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
                              0.75 * width,
                              0.02], facecolor="lightgoldenrodyellow")
     sliderMass = Slider(axSliderMass, "Mass", 0,
-                        data.Nm[it]-1, valinit=im, valfmt="%i")
+                        int(data.Nm[it]-1), valinit=im, valfmt="%i")
     axSliderMass.set_title("m = {:9.3e} g".format(data.m[it, im]))
     fig._widgets += [sliderMass]
 
@@ -342,7 +343,7 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
                              0.75 * width,
                              0.02], facecolor="lightgoldenrodyellow")
     sliderDist = Slider(axSliderDist, "Distance", 0,
-                        data.Nr[it]-1, valinit=ir, valfmt="%i")
+                        int(data.Nr[it]-1), valinit=ir, valfmt="%i")
     axSliderDist.set_title("r = {:9.3e} AU".format(data.r[it, ir]/c.au))
     fig._widgets += [sliderDist]
 
@@ -350,15 +351,14 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
 
         it = 0
         if data.Nt > 2:
-            it = np.int(np.floor(sliderTime.val))
+            it = int(np.floor(sliderTime.val))
             axSliderTime.set_title("t = {:9.3e} yr".format(data.t[it]/c.year))
-        im = np.int(np.floor(sliderMass.val))
+        im = int(np.floor(sliderMass.val))
         axSliderMass.set_title("m = {:9.3e} g".format(data.m[it, im]))
-        ir = np.int(np.floor(sliderDist.val))
+        ir = int(np.floor(sliderDist.val))
         axSliderDist.set_title("r = {:9.3e} AU".format(data.r[it, ir]/c.au))
 
         for row in plt00Collections:
-            ax00.collections.remove(row)
             plt00Collections.remove(row)
         plt00 = ax00.contourf(data.r[it, ...]/c.au,
                               data.m[it, ...],
@@ -371,7 +371,6 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
             plt00Collections.append(row)
         if show_St1:
             for row in plt00StCollections:
-                ax00.collections.remove(row)
                 plt00StCollections.remove(row)
             plt00St = ax00.contour(data.r[it, ...]/c.au,
                                    data.m[it, ...],
@@ -384,7 +383,6 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
                 plt00StCollections.append(row)
         if show_limits:
             for row in plt00DrCollections:
-                ax00.collections.remove(row)
                 plt00DrCollections.remove(row)
             plt00Dr = ax00.contour(data.r[it, ...]/c.au,
                                    data.m[it, ...],
@@ -396,7 +394,6 @@ def ipanel(data, filename="data", extension="hdf5", im=0, ir=0, it=0, show_limit
             for row in plt00Dr.collections:
                 plt00DrCollections.append(row)
             for row in plt00FrCollections:
-                ax00.collections.remove(row)
                 plt00FrCollections.remove(row)
             plt00Fr = ax00.contour(data.r[it, ...]/c.au,
                                    data.m[it, ...],
@@ -522,8 +519,8 @@ def _readdata(data, filename="data", extension="hdf5"):
 
     # Fragmentation limit
     b = vFrag**2 / (delta * cs**2)
-    with np.warnings.catch_warnings():
-        np.warnings.filterwarnings(
+    with warnings.catch_warnings():
+        warnings.filterwarnings(
             'ignore',
             r'invalid value encountered in sqrt')
         StFr = 1 / (2 * b) * (3 - np.sqrt(9 - 4 * b**2))
@@ -531,7 +528,7 @@ def _readdata(data, filename="data", extension="hdf5"):
     # Drift limit
     p = SigmaGas * OmegaK * cs / np.sqrt(2.*np.pi)
     StDr = np.zeros_like(StFr)
-    for i in range(np.int(Nt)):
+    for i in range(int(Nt)):
         _f = interp1d(np.log10(r[i, ...]), np.log10(
             p[i, ...]), fill_value='extrapolate')
         pi = 10.**_f(np.log10(ri[i, ...]))
